Description Usage Arguments Value Examples
Imagine you want to represent some kind of additional point, on the structure, within the structure, outside the structure. As you don't have the data for this representation, this function calculates the coordinates of such additional point based on a linear combination of two segments of the structure.
1 2 3 4 5 6 7 8 9 10 | beyondkick(
joint,
num.joint,
num.frame = NULL,
num.x,
num.y,
origin,
seg1,
seg2 = NULL
)
|
joint |
The joint dataset: the coordinates of the joints as a function of time |
num.joint |
The index of the column associated with the joint variable |
num.frame |
The index of the column associated with the frame variable |
num.x |
The index of the column associated with the x-axis variable represented on the graphical output |
num.y |
The index of the column associated with the y-axis variable represented on the graphical output |
origin |
The origin of the basis, a joint |
seg1 |
A triplet, the definition of the segment in terms of joints, and the coordinate on this segment |
seg2 |
A triplet, the definition of the segment in terms of joints, and the coordinate on this segment |
A supplementary dataset to be used with the beyondskeleton function
1 2 3 4 5 6 7 | ## Not run:
data(gaetan_apchagi)
plexus <- beyondkick(joint=gaetan_apchagi, num.joint=2, num.x = 3, num.y =4,
num.frame=6, origin="RIGHT_SHOULDER", seg1 = c("RIGHT_SHOULDER", "LEFT_SHOULDER", 1/2),
seg2=c("RIGHT_SHOULDER", "RIGHT_HIP", 1/2))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.